# Awesome Explorables ![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)

A curated list of awesome [explorable explanations](http://worrydream.com/#!/ExplorableExplanations). 

Inspired by Bret Vector and [awesome](https://github.com/sindresorhus/awesome).

## Contributing

You are welcome to create a PR to contribute. 

Please take a a look at [contribution guidelines](https://github.com/sp4ke/awesome-explorables/blob/master/CONTRIBUTING.md). 

#### *If you see a link or a project that is broken or no longer working, please submit a pull request to improve this file. Thank you !*

Join us on slack at [**#awesome-explorables**](https://awesome-explorables.com/) or reddit at [/r/explorables](https://www.reddit.com/r/explorables/)

## Contents

- [Math](#math) 
	- [Statistics And Probability](#statistics-and-probability)
	- [Linear Algebra](#linear-algebra)
	- [Trigonometry](#trigonometry)
	- [Logic](#logic)
- [Algorithms](#algorithms)
	- [Machine Learning And Neural Networks](#machine-learning-and-neural-networks)
	- [Programming](#programming)
	- [Data Structures](#data-structures)
- [Science](#science)
- [Physics](#physics)
- [Psychology - Human Machine Interface](#psychology-human-machine-interface)
- [Other](#other)
- [About Explorable Explanations](#about-explorable-explanations)
- [Tools & Resources](#tools-and-resources)
-  [Books](#books)

## Math

*[&#8593; top](#contents)*
* [Explained Visually](http://setosa.io/ev/)
  * [Image Kernels](http://setosa.io/ev/image-kernels/)
  * [Pi (π)](http://setosa.io/ev/pi/)
  * [Exponentiation](http://setosa.io/ev/exponentiation/)
* [Better Explained](https://betterexplained.com) - Math without endless memorization
* [Euclid: The Game](http://euclidthegame.com/)
* [The Hitchhiker's Guide To The Mandelbrot set](https://morr.cc/mandelbrot/) 
* [vf.rohanp.xyz](http://vf.rohanp.xyz/) - an interactive demonstration of vector field flow
* [How to Fold a Julia Fractal](http://acko.net/blog/how-to-fold-a-julia-fractal/) - Brilliant use of animation to show complex mathematical processes geometrically. Shows off Wittens' MathBox library. See also: To Infinity… And Beyond!, Animate Your Way to Glory. 
* [World of Mathematics](http://world.mathigon.org/)
* [A Primer on Bézier Curves](http://pomax.github.io/bezierinfo/) 
* [Math Insight](http://mathinsight.org/) - Copious interactive diagrams and ingenious experiments with digital publishing (threads, notation systems) 
* [Who’ll Freeze First? A Puzzle About Size and Staying Warm](http://noticing.co/on-size-and-warmth/)
* [Circles Sines and Signals](http://jackschaedler.github.io/circles-sines-signals/)  – a  compact primer on digital signal processing.



### Statistics And Probability
*[&#8593; top](#contents)*
* [Seeing Theory](http://students.brown.edu/seeing-theory/) - a visual introduction to probability and statistics
* [Principal Component Analysis](http://setosa.io/ev/principal-component-analysis/)
* [Conditional Probability](http://setosa.io/ev/conditional-probability/)
* [Ordinary Least Squares Regression](http://setosa.io/ev/ordinary-least-squares-regression/)
* [Markov Chains](http://setosa.io/ev/markov-chains/)
* [Science Isn't Broken](https://fivethirtyeight.com/features/science-isnt-broken/#part1) - On scientific method (p-values)
* [Humans Suck At Entropy](http://www.loper-os.org/bad-at-entropy/manmach.html) 
* [Simpson's Paradox](http://vudlab.com/simpsons/)
*  [Years You Have Left to Live, Probably](http://flowingdata.com/2015/09/23/years-you-have-left-to-live-probably/) - Great illustration of survival analysis, and of probabalistic proccesses in general. Memento mori. 
* [Interpreting Confidence Intervals](http://rpsychologist.com/d3/CI/) - See also: Interpreting Correlations & others. 

### Linear Algebra
*[&#8593; top](#contents)*
* [Eigenvectors and Eigenvalues](http://setosa.io/ev/eigenvectors-and-eigenvalues/)
* [Interactive 2d Matrix](http://ncase.me/matrix/)
* [Immersive Math](http://immersivemath.com/ila/)  – a linear algebra book with  ully interactive figures
* [Invitation to Another Dimension](http://maxgoldste.in/invitation-to-another-dimension/)


### Trigonometry
*[&#8593; top](#contents)*
* [Sine and Cosine](http://setosa.io/ev/sine-and-cosine/)


### Logic
*[&#8593; top](#contents)*
* [The Incredible Proof Machine](http://incredible.pm/) – a visual approach to propositional logic




## Algorithms

*[&#8593; top](#contents)*
* [Visualizing Algorithms](https://bost.ocks.org/mike/algorithms/) - visualizing algorithms, by mike bostock
* [visualgo.net](https://visualgo.net) - interactive computer science algorithms and data structures
* [Quicksort](https://illustrated-algorithms.now.sh/quicksort) - the quicksort algorithm, illustrated with playing cards
* [Second-Order Controls](https://medium.com/@max_goldstein/second-order-controls-5cee5ddc9d2d)
* [How to Use t-SNE Effectively](http://distill.pub/2016/misread-tsne/) - Visualizing high-dimensional data
* [Promisees](http://bevacqua.github.io/promisees/) - Promise visualization playground for the adventurous
* [Back to the Future of Handwriting Recognition](http://jackschaedler.github.io/handwriting-recognition/) - An Active Essay Revisiting the GRAIL Handwriting Recognizer
* [Bloom Filters](https://www.jasondavies.com/bloomfilter/) 
* [Calculating The Intersection Area of 3+ Circles](http://www.benfrederickson.com/calculating-the-intersection-of-3-or-more-circles/)
* [Line-intersection](http://bl.ocks.org/1wheel/464141fe9b940153e636) - Responsive parallel representations make the Bentley–Ottmann algorithm easier to understand. 
* [Split Packing: An Algorithm for Packing Circles with up to Critical Density](https://morr.cc/split-packing/)
* [VisuAlgo](http://visualgo.net/)
* [Coloring Maps](http://roadtolarissa.com/blog/2015/01/04/coloring-maps-with-d3/) - Transforming numbers into colors
* [Interactive Diagrams for Wikipedia](https://classes.soe.ucsc.edu/cmps179/Spring13/#Week9)
* [Visualizing Map Distortion](http://bl.ocks.org/enjalot/bd552e711b8325c64729)


### Machine Learning and Neural Networks
*[&#8593; top](#contents)*
* [r2d3.us](http://www.r2d3.us/visual-intro-to-machine-learning-part-1/) - a visual introduction to machine learning
* [Neural Networks And Deep Learning](http://neuralnetworksanddeeplearning.com/) - Free online interactive book about Neural Networks and Deep Learning.
* [playground.tensorflow.org](http://playground.tensorflow.org/) - a neural network playground
* [Attention and Augmented Recurrent Neural Networks](http://distill.pub/2016/augmented-rnns/)
* [Four Experiments in Handwriting with a Neural Network](http://distill.pub/2016/handwriting/)
* [Confounding Variables](http://bl.ocks.org/jmahabal/raw/8f010c62112dec083b559cb047a51048/)

### Programming
*[&#8593; top](#contents)*
* [Red Blob Games](http://www.redblobgames.com/) - visual and interactive ways of explaining math and computer algorithms 
	* [Introduction To A* ](http://www.redblobgames.com/pathfinding/a-star/introduction.html) – how pathfinding algorithms work, by amit patel
	* [Hexagonal Grids](http://www.redblobgames.com/grids/hexagons/) - an interactive guide on implementing hexagonal grids
	* [Intro To Graph Theory](http://www.redblobgames.com/pathfinding/grids/graphs.html)
* [Generating Fantasy Maps](http://mewo2.com/notes/terrain/) - generating fantasy maps – the math behind 
* [gamejolt.com](http://gamejolt.com/games/the-stranger-loop/10679) - topology, via asteroids, narrated
* [What is code?](http://www.bloomberg.com/graphics/2015-paul-ford-what-is-code/)


### Data Structures
*[&#8593; top](#contents)*
* [Quadtree](http://jimkang.com/quadtreevis/) - an interactive explanation of quadtrees, by jim kang
* [Bitcoin Blockchain](https://anders.com/blockchain/) - "blockchain demo" explains the basics behind decentralized cryptocurrencies like bitcoin



## Science
*[&#8593; top](#contents)*
* [ncase.me](http://ncase.me/simulating/) - simulating the world (in emoji😘)
* [ncase.me](http://ncase.me/neurons/) - neurotic neurons, an interactive animation on how exposure therapy works
* [Exploring Emergence](http://www.playfulinvention.com/emergence/index.html) -  an introduction to cellular automata (from 1996! requires flash.)
* [internet-atlas.net](http://internet-atlas.net/) - critical atlas of internet
* [Visualizing Projections](http://shaunlebron.github.io/visualizing-projections/) - visualizing multiple camera projection techniques
* [Entropy Explained, With Sheep](https://aatishb.github.io/entropy/)
* [Pink Trombone](http://dood.al/pinktrombone/) - A Hands-On Vocal Tract Simulation

## Physics
*[&#8593; top](#contents)*
* [arogozhnikov.github.io](https://arogozhnikov.github.io/2016/12/19/markov_chain_monte_carlo.html) - hamiltonian monte carlo explained
* [Nukemap](http://nuclearsecrecy.com/nukemap/) - nuclear explosion simulation tool by alex wellerstein
* [Angry Physics](http://ncase.me/birds/) 
* [PhET Home Page](https://phet.colorado.edu/) - "free interactive math and science simulations… based on extensive education research"
* [Interactive Introduction To Optical Modulation](https://shapescience.xyz/blog/interactive-introduction-to-optical-modulation/)



## Psychology Human Machine Interface
*[&#8593; top](#contents)*
* [To Build A Better Ballot](http://ncase.me/ballot/) – an interactive guide to alternative voting systems
* [recursivedrawing.com](http://recursivedrawing.com/) - by toby schachman lets you create complex patterns from simple building blocks
* [Parable Of the Polygons](http://ncase.me/polygons/)  – A simulation about segregation and diversity.
* [Learning By Doing](http://blog.ncase.me/i-do-and-i-understand/) 


## Other
*[&#8593; top](#contents)*
* [Ishkur's Guide To Electronic Music](http://techno.org/electronic-music-guide/) - 
* [kevinhayeswilson.com](https://kevinhayeswilson.com/redraw/) - redraw state boundaries with 2016 us election data.
* [How Uber Uses Psychological Tricks to Push Its Drivers’ Buttons](https://www.nytimes.com/interactive/2017/04/02/technology/uber-drivers-psychological-tricks.html?_r=0)


## About Explorable Explanations
*[&#8593; top](#contents)*
* [Explorable Explanations](http://explorableexplanations.com)
* [worrydream.com](http://worrydream.com/ScientificCommunicationAsSequentialArt/) - Scientific Communication As Sequential Art
* [worrydream.com](http://worrydream.com/LadderOfAbstraction/) - up and down the ladder of abstraction – a systemic approach to interactive visualization
* [worrydream.com](http://worrydream.com/ExplorableExplanations/) - Bret Victor's essay which coined the term "explorable explanations"
* [Reinventing Explanation](http://michaelnielsen.org/reinventing_explanation/) – prototyping an accessible explanation of simpson's paradox
* [blog.ncase.me](http://blog.ncase.me/explorable-explanations/) - design patterns for explorable explanations
* [simblob.blogspot.de](http://simblob.blogspot.de/2016/12/five-year-mission.html) - amit patel of red blob games looks back on 5 years of creating interactive explanations


## Tools And Resources
*[&#8593; top](#contents)*
* [Tangle](http://worrydream.com/Tangle/) Js Library for reactive documents
* [Outside the box](http://simblob.blogspot.nl/2016/10/outside-box.html) On SVG and Arrows.
* [Implementing Draggable Handles](http://simblob.blogspot.nl/2014/09/implementing-draggable-handles.html)
* [RedBlobGames - Making Of](simblob.blogspot.nl/search/label/making-of)
* [GeoGebra](https://www.geogebra.org/materials/) - dynamic mathematics for learning and teaching 
* [aprt.us](http://aprt.us/) - apparatus, an open-source graphics editor and programming environment for creating interactive diagrams
* [awesome-livecoding](https://github.com/lvm/awesome-livecoding) - a curated list of live-coding resources.
* [Self-Lang](http://www.selflanguage.org) prototype-based dynamic object-oriented programming language, environment, and virtual machine
* [Lively Kernel](http://lively-kernel.org)
* [Coeffects](http://tomasp.net/coeffects/) - Context-aware programming languages
* [INFO 3300 - Data-driven Web Applications](mimno.infosci.cornell.edu/info3300/)
* [Human Advancement Research Community - YC Research](https://harc.ycr.org)
* [Flex - YC Research](https://harc.ycr.org/flex/) - Interactive programming and solution exploration tools
  * [Ohm](https://github.com/harc/ohm) - Visual parser generator and toolkit for building interpreters and compilers.
  * [Chorus](http://www.chorus-home.org) - Visual mobile programming using spreadsheet concepts
* [Loopy](http://ncase.me/loopy/) - a tool for thinking in systems



## Books
*[&#8593; top](#contents)*
* [mindstorms.media.mit.edu](http://mindstorms.media.mit.edu/) - "mindstorms: children, computers, and powerful ideas", an influential 1980 book by seymour papert
* [Elements of Euclid](https://archive.org/details/firstsixbooksofe00eucl) - oliver byrne's edition of euclid's "elements" uses colored diagrams and symbols instead of letters to proof theorems about math and geometry
* [Envisioning Information](http://www.edwardtufte.com/tufte/books_ei)
* [Understanding Comics](http://scottmccloud.com/2-print/1-uc/) - "The pedagogical potential of the comic form is vast and mostly untapped" —Bret Victor 
* [A Topological Picturebook](http://www.amazon.com/Topological-Picturebook-George-K-Francis/dp/0387345426)
* [Dynamics, the Geometry of Behavior](http://www.aerialpress.com/DYN/)
* [Proofs without Words](http://www.amazon.com/Proofs-without-Words-Exercises-Classroom/dp/0883857006)
* [Relativity Visualized](http://www.amazon.com/Relativity-Visualized-Lewis-Carroll-Epstein/dp/093521805X)
* [The Shape of Space](http://www.amazon.com/Shape-Space-Chapman-Applied-Mathematics/dp/0824707095) 
* [Visual Group Theory](http://web.bentley.edu/empl/c/ncarter/vgt/)
